@@ -1,17 +1,42 @@
 #![allow(clippy::from_iter_instead_of_collect)]
 
-use std::collections::{BTreeSet, HashMap, HashSet};
+use std::collections::{BTreeMap, BTreeSet, HashMap, HashSet};
 use std::iter::FromIterator;
 
-use sn_dbc::{bls_dkg_id, Dbc, DbcContent, Mint, MintRequest, MintTransaction};
+use sn_dbc::{bls_dkg_id, Dbc, DbcContent, KeyManager, Mint, ReissueRequest, ReissueTransaction};
 
 use criterion::{black_box, criterion_group, criterion_main, Criterion};
 
 fn genesis(amount: u64) -> (Mint, bls_dkg::outcome::Outcome, Dbc) {
     let genesis_owner = bls_dkg_id();
-    let (genesis, genesis_dbc) = Mint::genesis(genesis_owner.public_key_set.clone(), amount);
 
-    (genesis, genesis_owner, genesis_dbc)
+    let mut genesis_node = Mint::new(KeyManager::new(
+        genesis_owner.public_key_set.clone(),
+        (0, genesis_owner.secret_key_share.clone()),
+        genesis_owner.public_key_set.public_key(),
+    ));
+
+    let (content, transaction, (mint_key_set, mint_sig_share)) =
+        genesis_node.issue_genesis_dbc(amount).unwrap();
+
+    let mint_sig = mint_key_set
+        .combine_signatures(vec![mint_sig_share.threshold_crypto()])
+        .unwrap();
+
+    let transaction_sigs = BTreeMap::from_iter(
+        transaction
+            .inputs
+            .iter()
+            .map(|in_hash| (*in_hash, (mint_key_set.public_key(), mint_sig.clone()))),
+    );
+
+    let genesis_dbc = Dbc {
+        content,
+        transaction,
+        transaction_sigs,
+    };
+
+    (genesis_node, genesis_owner, genesis_dbc)
 }
 
 fn bench_reissue_1_to_100(c: &mut Criterion) {
@@ -28,7 +53,7 @@ fn bench_reissue_1_to_100(c: &mut Criterion) {
         .map(|i| DbcContent::new(input_hashes.clone(), 1, i, owner_pub_key))
         .collect();
 
-    let transaction = MintTransaction { inputs, outputs };
+    let transaction = ReissueTransaction { inputs, outputs };
 
     let sig_share = genesis_owner
         .secret_key_share
@@ -39,7 +64,7 @@ fn bench_reissue_1_to_100(c: &mut Criterion) {
         .combine_signatures(vec![(0, &sig_share)])
         .unwrap();
 
-    let mint_request = MintRequest {
+    let reissue = ReissueRequest {
         transaction,
         input_ownership_proofs: HashMap::from_iter(vec![(
             genesis_dbc.name(),
@@ -52,10 +77,7 @@ fn bench_reissue_1_to_100(c: &mut Criterion) {
         b.iter(|| {
             genesis.reset_spendbook(spendbook.clone());
             genesis
-                .reissue(
-                    black_box(mint_request.clone()),
-                    black_box(input_hashes.clone()),
-                )
+                .reissue(black_box(reissue.clone()), black_box(input_hashes.clone()))
                 .unwrap();
         })
     });
@@ -78,7 +100,7 @@ fn bench_reissue_100_to_1(c: &mut Criterion) {
         )
     }));
 
-    let transaction = MintTransaction {
+    let transaction = ReissueTransaction {
         inputs,
         outputs: HashSet::from_iter(outputs.clone()),
     };
@@ -92,7 +114,7 @@ fn bench_reissue_100_to_1(c: &mut Criterion) {
         .combine_signatures(vec![(0, &sig_share)])
         .unwrap();
 
-    let mint_request = MintRequest {
+    let reissue = ReissueRequest {
         transaction,
         input_ownership_proofs: HashMap::from_iter(vec![(
             genesis_dbc.name(),
@@ -100,12 +122,22 @@ fn bench_reissue_100_to_1(c: &mut Criterion) {
         )]),
     };
 
-    let (transaction, transaction_sigs) = genesis.reissue(mint_request, input_hashes).unwrap();
+    let (transaction, transaction_sigs) = genesis.reissue(reissue, input_hashes).unwrap();
+
+    let (mint_key_set, mint_sig_share) = transaction_sigs.values().cloned().next().unwrap();
+
+    let mint_sig = genesis_owner
+        .public_key_set
+        .combine_signatures(vec![mint_sig_share.threshold_crypto()])
+        .unwrap();
 
     let dbcs = Vec::from_iter(outputs.into_iter().map(|content| Dbc {
         content,
         transaction: transaction.clone(),
-        transaction_sigs: transaction_sigs.clone(),
+        transaction_sigs: BTreeMap::from_iter(vec![(
+            genesis_dbc.name(),
+            (mint_key_set.public_key(), mint_sig.clone()),
+        )]),
     }));
 
     let merged_output = DbcContent::new(
@@ -115,7 +147,7 @@ fn bench_reissue_100_to_1(c: &mut Criterion) {
         bls_dkg_id().public_key_set.public_key(),
     );
 
-    let merge_transaction = MintTransaction {
+    let merge_transaction = ReissueTransaction {
         inputs: HashSet::from_iter(dbcs.clone()),
         outputs: HashSet::from_iter(vec![merged_output]),
     };
@@ -131,21 +163,18 @@ fn bench_reissue_100_to_1(c: &mut Criterion) {
         (dbc.name(), (owners[i].public_key_set.public_key(), sig))
     }));
 
-    let merge_mint_request = MintRequest {
+    let merge_reissue = ReissueRequest {
         transaction: merge_transaction,
         input_ownership_proofs,
     };
-    let inputs = merge_mint_request.transaction.blinded().inputs;
+    let inputs = merge_reissue.transaction.blinded().inputs;
 
     let spendbook = genesis.snapshot_spendbook();
     c.bench_function(&format!("reissue merge {} to 1", n_outputs), |b| {
         b.iter(|| {
             genesis.reset_spendbook(spendbook.clone());
             genesis
-                .reissue(
-                    black_box(merge_mint_request.clone()),
-                    black_box(inputs.clone()),
-                )
+                .reissue(black_box(merge_reissue.clone()), black_box(inputs.clone()))
                 .unwrap();
         })
     });
